<?php
/**
 * @version		$Id: doc.php 10094 2008-03-02 04:35:10Z instance $
 * @package		RubberDoc
 * @subpackage	Content
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.model');
jimport('joomla.utilities.string');
jimport('joomla.filesystem.file');

/**
 * RubberDoc Component Doc Model
 *
 * @package		Joomla
 * @subpackage	Doc
 * @since 1.5
 */
class RubberDocModelDoc extends JModel
{
	/**
	 * Doc id
	 *
	 * @var int
	 */
	private $id = null;

	/**
	 * item data
	 *
	 * @var array
	 */
	private $data = null;
	private $file = null;
	private $dirname = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		global $mainframe;
		
		parent::__construct();

		$array	= JRequest::getVar('cid', array(0), '', 'array');
		$edit	= JRequest::getVar('edit',true);
		if($edit)
			$this->setId((int)$array[0]);
			
		$config  =& JComponentHelper::getParams( 'com_rubberdoc' );
		$this->dirname = $config->get('rubberdoc_dir', 'rubberdoc');
	}

	/**
	 * Method to set the weblink identifier
	 *
	 * @access	public
	 * @param	int Doc identifier
	 */
	public function setId($id)
	{
		// Set doc id and wipe data
		$this->id	= $id;
		$this->data	= null;
		$this->file	= null;
	}

	public function getId()
	{
		return $this->id;
	}	

	/**
	 * Method to get a doc
	 *
	 * @since 1.5
	 */
	public function &getData()
	{
		// Load the doc data
		if (!$this->loadData())
		 $this->initData();

		return $this->data;
	}

	/**
	 * Tests if doc is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.5
	 */
	public function isCheckedOut( $uid=0 )
	{
		if ($this->loadData())
		{
			if ($uid) {
				return ($this->data->checked_out && $this->data->checked_out != $uid);
			} else {
				return $this->data->checked_out;
			}
		}
	}

	/**
	 * Method to checkin/unlock the doc
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function checkin()
	{
		if ($this->id)
		{
			$item = & $this->getTable('docs');
			if(! $item->checkin($this->id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return false;
	}

	/**
	 * Method to checkout/lock the weblink
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the article out
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function checkout($uid = null)
	{
		if ($this->id)
		{
			// Make sure we have a user id to checkout the doc with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & $this->getTable('docs');
			if(!$item->checkout($uid, $this->id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}



	/**
	 * Method to store the doc
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function store($data)
	{
		global $mainframe;
		
		$row =& $this->getTable('docs');

		// Bind the form fields to the docs table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		if(!$row->id)
		{
			// Create the timestamp for the create date
			$row->set('created', gmdate('Y-m-d H:i:s'));
			$row->set('downloads', 0);
			$row->set('access', 0);
		}
		
		// Create the timestamp for the modified date
		$row->set('modified', gmdate('Y-m-d H:i:s'));
		
		$file    = JRequest::getVar( 'Filedata', '', 'files', 'array' );
		if( is_array($file) && $file['size'] > 0 )
			$row->set('file_size', $file['size']);
		

		// Make sure the docs table is valid
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Store the docs table to the database
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$this->id = $row->get('id');
		
		if( JRequest::getInt('deletefile') )
			if( !$this->removeDoc( $this->id ) )
			{
				$this->setError(JText::_('Error removing the Document File'));
				return false;
			}
		
		$file = JRequest::getVar( 'Filedata', '', 'files', 'array' );
		
		if( $file['size'] > 0 )
			if (!$this->uploadDoc()) 
			{
				$this->setError(JText::_('Error uploading the Document File'));
				return false;
			}

		return true;
	}

	/**
	 * Method to remove a doc
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function delete($cid = array())
	{
		global $mainframe;
		
		$result = false;

		if (count( $cid ))
		{
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );
			
			$table =& $this->getTable('docs');
			
			$query = 'SELECT file FROM '.$table->getTableName()
			.' WHERE id IN ( '.$cids.' )'
			;
			$this->_db->setQuery( $query );
			$files = $this->_db->loadResultArray();
			
			
			
			foreach( $files as $fileName )
			{
				$filepath = JPath::clean(JPATH_SITE.DS.$this->dirname.DS.$fileName );
				if(JFile::exists( $filepath ))
					JFile::delete( $filepath );
			}
			
			$query = '' 
				.' DELETE FROM '.$table->getTableName()
				.' WHERE id IN ( '.$cids.' )'
				;
			$this->_db->setQuery( $query );
			if(!$this->_db->query()) 
			{
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}

		return true;
	}

	/**
	 * Method to (un)publish a doc
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function publish($cid = array(), $publish = 1)
	{
		$user 	=& JFactory::getUser();

		if (count( $cid ))
		{
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );

			$table =& $this->getTable('docs');

			$query = 'UPDATE '.$table->getTableName()
				. ' SET published = '.(int) $publish
				. ' WHERE id IN ( '.$cids.' )'
				. ' AND ( checked_out = 0 OR ( checked_out = '.(int) $user->get('id').' ) )'
			;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}

		return true;
	}



	/**
	 * Method to load content doc data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	private function loadData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$this->data =& $this->getTable('docs');			
			$this->data->load( (int) $this->id );			
			return (boolean) $this->data;
		}
		return true;
	}

	/**
	 * Method to initialise the doc data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	private function initData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$this->data =& $this->getTable('docs');
			return (boolean) $this->data;
		}
		return true;
	}
	
	
	private function uploadDoc()
	{
		global $mainframe, $option;
		
		if( !$this->id )
			return false;
		
		
		$file    	= JRequest::getVar( 'Filedata', '', 'files', 'array' );
		$err 		= '';
		$format		= JRequest::getVar( 'format', 'html', '', 'cmd');
		$config  	=& JComponentHelper::getParams( 'com_media' );
		
		if( is_array($file) && $file['size'] > 0 )
		{
			if( $file['size'] > $config->get('upload_maxsize') )
			{
				$this->setError( JText::_('File Size is too large. Maximum file size is '.( $config->get('upload_maxsize') / 1000 ).' KB') );
				return false;
			}
		}
		
		$temp 		= explode('.', $file['name']);
		$extension 	= array_pop( $temp );
		$fileTitle	= implode('_', $temp );
		
		$this->removeDoc( $this->id );
		
		//create a new file name
		$fileName = md5($fileTitle.date('U')).'.'.$extension;
		
		$filepath = JPath::clean(JPATH_SITE.DS.$this->dirname.DS.$fileName );
		
		if (!JFile::upload($file['tmp_name'], $filepath))
		{
			$this->setError( JText::_('Error uploading the file') );
			return false;
		}
		
		$table =& $this->getTable('docs');
		$query = 'UPDATE '.$table->getTableName()
		.' SET file = \''.$fileName.'\' '
		.' WHERE id='. (int) $this->id
		;
		
		$this->_db->setQuery( $query );
		$this->_db->query();
				
		return true;
	}
	
	private function removeDoc( $id )
	{
		global $mainframe, $option;
		
		if( !$id )
			return false;
		
		$table =& $this->getTable('docs');
		if( !$table->load( $this->id ) )
		{
			$this->setError( JText::_('Failed loading the Document record from the Database!') );
			return false;
		}
		
		$fileName = $table->get('file');
		
		$query = 'UPDATE '.$table->getTableName()
		.' SET file = "" '
		.' WHERE id='. (int) $id
		;
		
		$this->_db->setQuery( $query );
		$this->_db->query();
		
		$filepath = JPath::clean(JPATH_SITE.DS.$this->dirname.DS.$fileName);

		if(JFile::exists( $filepath ))
			JFile::delete( $filepath );
		
		return true;
	}
	
	private function changeAccess()
	{
		
	}

// end class	
}