<?php
/**
 * @version		$Id: docs.php 10094 2008-03-02 04:35:10Z instance $
 * @package		Joomla
 * @subpackage	RubberDoc
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
 * Joomla! is free software. This version may have been modified pursuant to the
 * GNU General Public License, and as distributed it includes or is derivative
 * of works licensed under the GNU General Public License or other free or open
 * source software licenses. See COPYRIGHT.php for copyright notices and
 * details.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RubberDoc Component Docs Model
 *
 * @package		Joomla
 * @subpackage	RubberDoc
 * @since 1.5
 */
class RubberDocModelDocs extends JModel
{
	/**
	 * Category ata array
	 *
	 * @var array
	 */
	private $data = null;

	/**
	 * Category total
	 *
	 * @var integer
	 */
	private $total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	private $pagination = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe, $option;

		// Get the pagination request variables
		$limit		= $mainframe->getUserStateFromRequest( 'global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int' );
		$limitstart	= $mainframe->getUserStateFromRequest( $option.'.limitstart', 'limitstart', 0, 'int' );

		// In case limit has been changed, adjust limitstart accordingly
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	/**
	 * Method to get items data
	 *
	 * @access public
	 * @return array
	 */
	public function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$query = $this->buildQuery();
			$this->data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
		}

		return $this->data;
	}

	/**
	 * Method to get the total number of items
	 *
	 * @access public
	 * @return integer
	 */
	public function getTotal()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->total))
		{
			$query = $this->buildQuery();
			$this->total = $this->_getListCount($query);
		}

		return $this->total;
	}

	/**
	 * Method to get a pagination object for the items
	 *
	 * @access public
	 * @return integer
	 */
	public public function getPagination()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->pagination))
		{
			jimport('joomla.html.pagination');
			$this->pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->pagination;
	}

	private function buildQuery()
	{
		$table =& $this->getTable('docs');
		
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->buildContentWhere();
		$orderby	= $this->buildContentOrderBy();

		$query = ' SELECT a.*, cc.title AS category, u.name AS editor, g.name AS groupname '
			. ' FROM '.$table->getTableName().' AS a '
			. ' LEFT JOIN #__categories AS cc ON cc.id = a.category_id '
			. ' LEFT JOIN #__users AS u ON u.id = a.checked_out '
			. ' LEFT JOIN #__groups AS g ON g.id = a.access'
			. $where
			. $orderby
		;

	 //	echo str_replace('#_', 'jos', $query).'<br>';

		return $query;
	}

	private function buildContentOrderBy()
	{
		global $mainframe, $option;

		$filter_order		= $mainframe->getUserStateFromRequest( $option.'filter_order',		'filter_order',		'a.id',	'int' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'filter_order_Dir',	'filter_order_Dir',	'',		'word');

		if ($filter_order == 'a.id'){
			$orderby 	= ' ORDER BY category, a.id '.$filter_order_Dir;
		} else {
			$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.' , category, a.ordering ';
		}

		return $orderby;
	}

	private function buildContentWhere()
	{
		global $mainframe, $option;
		$db					=& JFactory::getDBO();
		$filter_state		= $mainframe->getUserStateFromRequest( $option.'filter_state',		'filter_state',			'',			'word' );
		$filter_category_id	= $mainframe->getUserStateFromRequest( $option.'filter_category_id',	'filter_category_id',	'0',		'int' );
		$filter_order		= $mainframe->getUserStateFromRequest( $option.'filter_order',		'filter_order',			'a.id',		'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'filter_order_Dir',	'filter_order_Dir',		'',			'word' );
		$search				= $mainframe->getUserStateFromRequest( $option.'search',			'search',				'',			'string' );
		$search				= JString::strtolower( $search );

		$where = array();

		if ($filter_category_id > 0) {
			$where[] = 'a.category_id = '.(int) $filter_category_id;
		}
		if ($search) {
			$where[] = ' ( LOWER( a.title ) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false )
			.' OR LOWER( a.description ) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false )
			.' OR LOWER( a.metadesc ) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false )
			.' OR LOWER( a.metakey ) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false )
			.' ) '
			;
		}
		if ( $filter_state ) {
			if ( $filter_state == 'P' ) {
				$where[] = 'a.published = 1';
			} else if ($filter_state == 'U' ) {
				$where[] = 'a.published = 0';
			}
		}

		$where 		= ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );

		return $where;
	}

// end class
}
