<?php

// Check to ensure this file is included in Joomla!
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.plugin.plugin' );
jimport( 'joomla.filter.filteroutput');



/**
 * Example Content Plugin
 *
 * @package		Joomla
 * @subpackage	RubberDoc
 * @since 		1.5
 */
class plgContentRubberdoc extends JPlugin
{

	/**
	 * CONSTRUCTOR
	 * @param object $subject The object to observe
	 * @param object $params  The object that holds the plugin parameters
	 * @since 1.5
	 */
	function __construct( &$subject, $params )
	{
		parent::__construct( $subject, $params );
	}

	/**
	 * Example prepare content method
	 *
	 * Method is called by the view
	 *
	 * @param 	object		The article object.  Note $article->text is also available
	 * @param 	object		The article params
	 * @param 	int			The 'page' number
	 */
	public function onPrepareContent( &$article, &$params, $limitstart )
	{
		global $mainframe;


		// simple performance check to determine whether bot should process further
		if ( JString::strpos( $article->text, '{docs' ) === false ) {
			return true;
		}
		
		// Get plugin info
		$plugin =& JPluginHelper::getPlugin('content', 'rubberdoc');
		$pluginParams = new JParameter( $plugin->params );
		
		// define the regular expression for the bot
		$docsRegex = "#{docs\s*(.*?)}(.*?){/docs}#s";
		$catRegex = "#{docs\s*category=\"(.*?)\"}#s";
		
		// check whether plugin has been unpublished
		if ( !$pluginParams->get( 'enabled', 1 ) ) {
			$article->text = preg_replace( $docsRegex, '', $article->text );
			$article->text = preg_replace( $catRegex, '', $article->text );
			return true;
		}
		
		$article->text = preg_replace_callback( $catRegex, 'proccessDocCategories', $article->text );
		$article->text = preg_replace_callback( $docsRegex, 'proccessDocItems', $article->text );
		
		return;
	}

// end class
}



function proccessDocCategories(&$matches)
{
	global $mainframe;
	
	$categoryAlias = trim( $matches[1] );
	
	if( $categoryAlias == '' )
		return '';
		
	$db =& JFactory::getDBO();
		
	$query = 'SELECT d.id, d.title, d.alias '
	.' FROM #__rubberdoc_docs AS d '
	.' LEFT JOIN #__categories AS c ON d.category_id = c.id '
	.' WHERE c.alias = \''.$categoryAlias.'\' '
	.' AND d.file_size > 0 '
	.' AND c.published = 1'
	.' AND d.published = 1'
	.' ORDER BY d.modified '
	;
	
	//echo str_replace('#_', 'jos', $query); 
	
	$db->setQuery( $query );
	$docs = $db->loadObjectList();
	
	if( count($docs) == 0 )
		return '';
	
	$html  = "\n".'<ul class="rubbderdoc">'."\n";
	$baseURI   = JFactory::getURI()->base();	
	foreach( $docs as $doc )
		$html .= '<li><a href="'.JRoute::_($baseURI.'index.php?option=com_rubberdoc&view=doc&id='.$doc->id.'&format=raw', false).'" title="'.$doc->title.'" >'.$doc->title.'</a></li>'."\n";
		
	$html .= '<ul>'."\n";

	return $html;
}

function proccessDocItems(&$matches)
{
	global $mainframe;
	$baseURI   = JFactory::getURI()->base();
	
	$aliases = explode(',', JFilterOutput::cleanText( $matches[0] ) );
	
	if( count($aliases) == 0 )
		return '';
		
	for($i=0; $i<count($aliases); $i++)
		$aliases[$i] = "'".trim( $aliases[$i] )."'"; 	
	
	$db =& JFactory::getDBO();
	
	$query = 'SELECT id, title, alias'
	.' FROM #__rubberdoc_docs '
	.' WHERE alias IN ( '.implode(',', $aliases).' )'
	.' AND file_size > 0'
	.' AND published = 1'
	;
	
	$db->setQuery( $query );
	
	$docs = $db->loadObjectList();
	
	switch( count($docs) )
	{
		case 0:
			$html = '';
		break;
		
		case 1:
			$html = '<a href="'.JRoute::_( $baseURI.'index.php?option=com_rubberdoc&view=doc&id='.$docs[0]->id.'&format=raw', false).'" title="'.$docs[0]->title.'" >'.$docs[0]->title.'</a>';
		break;
		
		default:
		
		$html  = "\n".'<ul class="rubbderdoc">'."\n";
		
		foreach( $docs as $doc )
			$html .= '<li><a href="'.JRoute::_($baseURI.'index.php?option=com_rubberdoc&view=doc&id='.$doc->id.'&format=raw', false).'" title="'.$doc->title.'" >'.$doc->title.'</a></li>'."\n";
		
		$html .= '<ul>'."\n";
	}

	return $html;
}


