<?php

// Check to ensure this file is included in Joomla!
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RubberDoc Component Categories Model
 *
 * @author		Rastin Mehr <info@rmdstudio.com>
 * @package		Joomla
 * @subpackage	RubberDoc
 * @since 1.5
 */
class RubberDocModelCategories extends JModel
{
	/**
	 * Categories data array
	 *
	 * @var array
	 */
	private $data = null;

	/**
	 * Categories total
	 *
	 * @var integer
	 */
	private $total = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */

	function __construct()
	{
		parent::__construct();
	}

	/**
	 * Method to get weblink item data for the category
	 *
	 * @access public
	 * @return array
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$query = $this->buildQuery();
			$this->data = $this->_getList($query);
		}

		return $this->data;
	}

	/**
	 * Method to get the total number of weblink items for the category
	 *
	 * @access public
	 * @return integer
	 */
	public function getTotal()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->total))
		{
			$query = $this->buildQuery();
			$this->total = $this->_getListCount($query);
		}

		return $this->total;
	}

	private function buildQuery()
	{
		$user =& JFactory::getUser();
		$aid = $user->get('aid', 0);

		$table =& $this->getTable('docs');

		//Query to retrieve all categories that belong under the web links section and that are published.
		$query = 'SELECT cc.*, COUNT(a.id) AS numlinks,'
			.' CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(\':\', cc.id, cc.alias) ELSE cc.id END as slug'
			.' FROM #__categories AS cc'
			.' LEFT JOIN '.$table->getTableName().' AS a ON a.category_id = cc.id'
			.' WHERE a.published = 1'
			.' AND section = \'com_rubberdoc\''
			.' AND cc.published = 1'
			.' AND cc.access <= '.(int) $aid
			.' AND a.access <= '.(int) $aid
			.' GROUP BY cc.id'
			.' ORDER BY cc.ordering';

		return $query;
	}

// end class
}