<?php

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RubberDoc Component Category Model
 *
 * @author		Rastin Mehr <info@rmdstudio.com>
 * @package		RubberDoc
 * @subpackage	
 * @since 1.5
 */
class RubberDocModelCategory extends JModel
{
	/**
	 * Category id
	 *
	 * @var int
	 */
	private $id = null;

	/**
	 * Category ata array
	 *
	 * @var array
	 */
	private $data = null;

	/**
	 * Category total
	 *
	 * @var integer
	 */
	private $total = null;

	/**
	 * Category data
	 *
	 * @var object
	 */
	private $category = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	private $pagination = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe;

		$config = JFactory::getConfig();

		// Get the pagination request variables
		$this->setState('limit', $mainframe->getUserStateFromRequest('com_rubberdoc.limit', 'limit', $config->getValue('config.list_limit'), 'int'));
		$this->setState('limitstart', JRequest::getVar('limitstart', 0, '', 'int'));

		// In case limit has been changed, adjust limitstart accordingly
		$this->setState('limitstart', ($this->getState('limit') != 0 ? (floor($this->getState('limitstart') / $this->getState('limit')) * $this->getState('limit')) : 0));

		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
		$this->setState('filter_keyword', JRequest::getCmd('filter_keyword', ''));

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
	}

	/**
	 * Method to set the category id
	 *
	 * @access	public
	 * @param	int	Category ID number
	 */
	public function setId($id)
	{
		// Set category ID and wipe data
		$this->id			= $id;
		$this->category	= null;
	}

	/**
	 * Method to get weblink item data for the category
	 *
	 * @access public
	 * @return array
	 */
	public function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$query = $this->buildQuery();
			$this->data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));

			$total = count($this->data);
			for($i = 0; $i < $total; $i++)
			{
				$item =& $this->data[$i];
				$item->slug = $item->id.':'.$item->alias;
			}
		}

		return $this->data;
	}

	/**
	 * Method to get the total number of weblink items for the category
	 *
	 * @access public
	 * @return integer
	 */
	public function getTotal()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->total))
		{
			$query = $this->buildQuery();
			$this->total = $this->_getListCount($query);
		}

		return $this->total;
	}

	/**
	 * Method to get a pagination object of the weblink items for the category
	 *
	 * @access public
	 * @return integer
	 */
	public function getPagination()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->pagination))
		{
			jimport('joomla.html.pagination');
			$this->pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->pagination;
	}

	/**
	 * Method to get category data for the current category
	 *
	 * @since 1.5
	 */
	public function getCategory()
	{
		// Load the Category data
		if ($this->loadCategory())
		{
			// Initialize some variables
			$user = &JFactory::getUser();

			// Make sure the category is published
			if (!$this->category->published) {
				JError::raiseError(404, JText::_("Resource Not Found"));
				return false;
			}
			// check whether category access level allows access
			if ($this->category->access > $user->get('aid', 0)) {
				JError::raiseError(403, JText::_("ALERTNOTAUTH"));
				return false;
			}
		}
		return $this->category;
	}

	/**
	 * Method to load category data if it doesn't exist.
	 *
	 * @access	private
	 * @return	boolean	True on success
	 */
	private function loadCategory()
	{
		if (empty($this->category))
		{
			// current category info
			$query = 'SELECT c.*, ' .
				' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug '.
				' FROM #__categories AS c' .
				' WHERE c.id = '. (int) $this->id .
				' AND c.section = "com_rubberdoc"'
				;
				
		//	echo str_replace('#_', 'jos', $query);
				
			$this->_db->setQuery($query, 0, 1);
			$this->category = $this->_db->loadObject();
		}
		return true;
	}

	private function buildQuery()
	{
		global $mainframe, $option;
		
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');
		$filter_keyword		= $this->getState('filter_keyword');

		$filter_order		= JFilterInput::clean($filter_order, 'cmd');
		$filter_order_dir	= JFilterInput::clean($filter_order_dir, 'word');
		$filter_keyword		= JFilterInput::clean($filter_keyword, 'word');

		$user =& JFactory::getUser();
		$aid = $user->get('aid', 0);

		$where = array();
		$where[] = ' category_id = '. (int) $this->id;
		$where[] = ' published = 1 ';
		$where[] = ' access <= '.(int) $aid;

		if( $filter_keyword )
		{
			$where[] = ' ( '
			.' LOWER( title ) LIKE \'%'.$filter_keyword.'%\' '
			.' OR LOWER( alias ) LIKE \'%'.$filter_keyword.'%\' '
			.' OR LOWER( description ) LIKE \'%'.$filter_keyword.'%\' '
			.' OR LOWER( metadesc ) LIKE \'%'.$filter_keyword.'%\' '
			.' OR LOWER( metakey ) LIKE \'%'.$filter_keyword.'%\' '
			.' ) '
			;
		}

		$where 	= ' WHERE '.implode( ' AND ', $where );

		$docTable =& $this->getTable('docs');

		// We need to get a list of all documents in the given category
		$query = 'SELECT *' .
			' FROM '.$docTable->getTableName() .
			$where .
			' ORDER BY '. $filter_order .' '. $filter_order_dir
			;

		return $query;
	}

// end class
}
