<?php

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * RubberDoc Component Doc Model
 *
 * @author		Rastin Mehr <rastin.mehr@joomla.org>
 * @package		Joomla
 * @subpackage	RubberDoc
 * @since 1.5
 */
class RubberDocModelDoc extends JModel
{
	/**
	 * Doc id
	 *
	 * @var int
	 */
	private $id = null;

	/**
	 * Doc data
	 *
	 * @var array
	 */
	private $data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
	}

	/**
	 * Method to set the doc identifier
	 *
	 * @access	public
	 * @param	int doc identifier
	 */
	public function setId($id)
	{
		// Set doc id and wipe data
		$this->id	= $id;
		$this->data	= null;
	}

	/**
	 * Method to get a doc
	 *
	 * @since 1.5
	 */
	public function &getData()
	{
		if (!$this->loadData())
			$this->initData();

		return $this->data;
	}

	/**
	 * Method to increment the hit counter for the doc
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	public function hit()
	{
		global $mainframe;

		if ($this->id)
		{
			$doc = & $this->getTable('docs');
			$doc->hit($this->id);
			return true;
		}
		return false;
	}



	/**
	 * Method to load content doc data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	private function loadData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			
			$this->data =& $this->getTable('docs');
		
			$user =& JFactory::getUser();
			$aid = $user->get('aid', 0);
			
			$query = 'SELECT *'
			.' FROM '.$this->data->getTableName().' '
			.' WHERE id = '. (int) $this->id
			.' AND access <= '.(int) $aid
			.' AND published = 1'
			;
			
			$this->_db->setQuery( $query );
			$object = $this->_db->loadObject();

			$this->data->setProperties( $this->_db->loadObject() );
			
			return (boolean) $this->data;
		}
		
		return true;
	}

	/**
	 * Method to initialise the doc data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	private function initData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->data))
		{
			$this->data =& $this->getTable('docs');
			return (boolean) $this->data;
		}
		return true;
	}
}
?>
